﻿using System.Collections.Generic;
using System.Linq;

namespace TestProject
{
    /// <summary>
    /// 데이터 컨텍스트
    /// </summary>
    public static class DataContext
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Static
        //////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 국가 리스트
        /// </summary>
        private static readonly List<Country> _countryList;

        /// <summary>
        /// 도시 리스트
        /// </summary>
        private static readonly List<City> _cityList;

        /// <summary>
        /// 전화 리스트
        /// </summary>
        private static readonly List<Phone> _phoneList;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Static

        #region 생성자 - DataContext()

        /// <summary>
        /// 생성자
        /// </summary>
        static DataContext()
        {
            _countryList = new List<Country>()
            {
                new Country() { ID = 1, Name = "USA"          , CountryCode = "1"  },
                new Country() { ID = 2, Name = "Germany"      , CountryCode = "49" },
                new Country() { ID = 3, Name = "France"       , CountryCode = "33" },
                new Country() { ID = 4, Name = "Great Britain", CountryCode = "44" },
                new Country() { ID = 5, Name = "Italy"        , CountryCode = "39" },
                new Country() { ID = 6, Name = "Russia"       , CountryCode = "7"  }
            };

            _cityList = new List<City>()
            {
                new City() { ID = 1 , Name = "Washington"   , CityCode = "202" , CountryCode = "1"  },
                new City() { ID = 2 , Name = "Los Angeles"  , CityCode = "213" , CountryCode = "1"  },
                new City() { ID = 3 , Name = "San Francisco", CityCode = "415" , CountryCode = "1"  },
                new City() { ID = 4 , Name = "New-York"     , CityCode = "718" , CountryCode = "1"  },
                new City() { ID = 5 , Name = "Berlin"       , CityCode = "30"  , CountryCode = "49" },
                new City() { ID = 6 , Name = "Bonn"         , CityCode = "228" , CountryCode = "49" },
                new City() { ID = 7 , Name = "Munhen"       , CityCode = "89"  , CountryCode = "49" },
                new City() { ID = 8 , Name = "Paris"        , CityCode = "1"   , CountryCode = "33" },
                new City() { ID = 9 , Name = "Lion"         , CityCode = "19"  , CountryCode = "33" },
                new City() { ID = 10, Name = "London"       , CityCode = "1274", CountryCode = "44" },
                new City() { ID = 11, Name = "Glasgo"       , CityCode = "141" , CountryCode = "44" },
                new City() { ID = 12, Name = "Rome"         , CityCode = "6"   , CountryCode = "39" },
                new City() { ID = 13, Name = "Milan"        , CityCode = "2"   , CountryCode = "39" },
                new City() { ID = 14, Name = "Moscow"       , CityCode = "495" , CountryCode = "7"  }
            };

            _phoneList = new List<Phone>()
            {
                new Phone() { ID = 1, Name = "xxx", CountryCode = "39", CityCode = "6"   },
                new Phone() { ID = 2, Name = "yyy", CountryCode = "33", CityCode = "19"  },
                new Phone() { ID = 3, Name = "zzz", CountryCode = "1" , CityCode = "202" }
            };
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Static
        //////////////////////////////////////////////////////////////////////////////// Public

        #region 국가 리스트 구하기 - GetCountryList()

        /// <summary>
        /// 국가 리스트 구하기
        /// </summary>
        /// <returns>국가 리스트</returns>
        public static List<Country> GetCountryList()
        {
            return _countryList;
        }

        #endregion
        #region 도시 리스트 구하기 - GetCityList()

        /// <summary>
        /// 도시 리스트 구하기
        /// </summary>
        /// <returns>도시 리스트</returns>
        public static List<City> GetCityList()
        {
            return _cityList;
        }

        #endregion
        #region 도시 리스트 구하기 - GetCityList(countryCode)

        /// <summary>
        /// 도시 리스트 구하기
        /// </summary>
        /// <param name="countryCode">국가 코드</param>
        /// <returns>도시 리스트</returns>
        public static List<City> GetCityList(string countryCode)
        {
            return DataContext._cityList.Where(city => city.CountryCode == countryCode).ToList();
        }

        #endregion
        #region 전화 리스트 구하기 - GetPhoneList()

        /// <summary>
        /// 전화 리스트 구하기
        /// </summary>
        /// <returns>전화 리스트</returns>
        public static List<Phone> GetPhoneList()
        {
            return _phoneList;
        }

        #endregion
    }
}