﻿using System;

using DevExpress.XtraEditors;
using DevExpress.XtraGrid.Views.Grid;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : XtraForm
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            Load                                                  += Form_Load;
            this.countryRepositoryItemLookUpEdit.EditValueChanged += countryRepositoryItemLookUpEdit_EditValueChanged;
            this.gridView.ShownEditor                             += gridView_ShownEditor;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 폼 로드시 처리하기 - Form_Load(sender, e)

        /// <summary>
        /// 폼 로드시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void Form_Load(object sender, EventArgs e)
        {
            this.countryBindingSource.DataSource = DataContext.GetCountryList();
            this.cityBindingSource.DataSource    = DataContext.GetCityList();
            this.phoneBindingSource.DataSource   = DataContext.GetPhoneList();
        }

        #endregion
        #region 국가 저장소 항목 룩업 에디터 편집 값 변경시 처리하기 - countryRepositoryItemLookUpEdit_EditValueChanged(sender, e)

        /// <summary>
        /// 국가 저장소 항목 룩업 에디터 편집 값 변경시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void countryRepositoryItemLookUpEdit_EditValueChanged(object sender, EventArgs e)
        {
            this.gridView.PostEditor();

            this.gridView.SetFocusedRowCellValue("CityCode", null);
        }

        #endregion
        #region 그리드 뷰 에디터 표시 후 처리하기 - gridView_ShownEditor(sender, e)

        /// <summary>
        /// 그리드 뷰 에디터 표시 후 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void gridView_ShownEditor(object sender, EventArgs e)
        {
            GridView gridView = sender as GridView;

            if(gridView.FocusedColumn.FieldName == "CityCode")
            {
                LookUpEdit lookUpEdit = gridView.ActiveEditor as LookUpEdit;

                string countryCode = Convert.ToString(gridView.GetFocusedRowCellValue("CountryCode"));

                lookUpEdit.Properties.DataSource = DataContext.GetCityList(countryCode);
            }
        }

        #endregion
    }
}